<?php
/*
Plugin Name: WhatsCRM
Plugin URI: https://www.xrobot.tech
Description: WhatsCRM 独立站客服系统
Version: 1.0.0
Author: xrobot.tech
Author URI: https://www.xrobot.tech
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: whatscrm
Domain Path: /languages
License:     GPL2
 
{Plugin Name} is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.
 
{Plugin Name} is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with {Plugin Name}. If not, see {License URI}.
*/

/**
 * custom option and settings
 */
function whatscrm_settings_init()
{
    // register a new setting for whatscrm page
    register_setting('whatscrm', 'whatscrm_options');

    // register a new section in the whatscrm page
    add_settings_section(
        'whatscrm_section_developers',
        __('客服设置', 'whatscrm'),
        'whatscrm_section_developers_cb',
        'whatscrm'
    );

    add_settings_field(
        'whatscrm_field_link',
        __('客服地址', 'whatscrm'),
        'whatscrm_field_link_cb',
        'whatscrm',
        'whatscrm_section_developers',
        []
    );
}

/**
 * register our whatscrm_settings_init to the admin_init action hook
 */
add_action('admin_init', 'whatscrm_settings_init');

// 在前端页面尾部插入脚本
function insert_data_frontend()
{
    $value = get_option('whatscrm_options');
    echo '<script src="' . $value . '&t=1.0.0"></script>';
}
add_action('wp_footer', 'insert_data_frontend');

/**
 * custom option and settings:
 * callback functions
 */

// developers section cb

// section callbacks can accept an $args parameter, which is an array.
// $args have the following keys defined: title, id, callback.
// the values are defined at the add_settings_section() function.
function whatscrm_section_developers_cb($args)
{
    ?>
    <p id=<?php echo esc_attr($args['id']); ?>></p>
    <?php
}

// pill field cb

// field callbacks can accept an $args parameter, which is an array.
// $args is defined at the add_settings_field() function.
// wordpress has magic interaction with the following keys: label_for, class.
// the label_for key value is used for the for attribute of the <label>.
// the class key value is used for the class attribute of the <tr> containing the field.
// you can add custom key value pairs to be used inside your callbacks.
function whatscrm_field_link_cb($args)
{
    // get the value of the setting we've registered with register_setting()
    $value = get_option('whatscrm_options');
    echo '<textarea type="text" class="regular-text" id="whatscrm_field_link" name="whatscrm_options">' . esc_attr($value) . '</textarea>';
}


function whatscrm_options_page()
{
    add_options_page(
        'WhatsCRM',
        'WhatsCRM 选项',
        'manage_options',
        'whatscrm',
        'whatscrm_options_page_html'
    );
}

add_action('admin_menu', 'whatscrm_options_page');

function whatscrm_options_page_html()
{
    // check user capabilities
    if (!current_user_can('manage_options')) {
        return;
    }
    ?>
    <div class=wrap>
        <h1><?= esc_html(get_admin_page_title()); ?></h1>
        <form action=options.php method=post>
            <?php
            // output security fields for the registered setting whatscrm_options
            settings_fields('whatscrm');
            // output setting sections and their fields
            // (sections are registered for whatscrm, each field is registered to a specific section)
            do_settings_sections('whatscrm');
            // output save settings button
            submit_button('保存设置');
            ?>
        </form>
    </div>
    <?php
}

